package com.jkcredit.data.datastorage.service.identityInfoService;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.jkcredit.data.datastorage.mapper.IdentityInfoMapper;
import com.jkcredit.data.datastorage.model.dto.IdentityInfoDto;
import com.jkcredit.data.datastorage.model.po.IdentityInfoPo;
import com.jkcredit.data.datastorage.model.vo.CommonResponseVo;
import com.jkcredit.data.datastorage.util.CommonUtil;
import com.jkcredit.data.datastorage.util.DESedeUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * @description:
 * @author: xusonglin
 * @create: 2020/7/6 15:33
 * @version: V1.0
 **/
@Slf4j
@Service
public class IdentityInfoServiceImpl implements IdentityInfoService {
    @Value("${project.decryptKey}")
    private String decryptKey;
    @Resource
    IdentityInfoMapper mapper;

    @Override
    public CommonResponseVo saveIdentityInfo(String encodeParam) {
        String requestId = CommonUtil.getRequestId();
        log.info("requestId:{}, param:{}", requestId, encodeParam);

        JSONObject requestObject = JSON.parseObject(encodeParam);
        if (StringUtils.isBlank(requestObject.getString("param"))) {
            log.error("requestId:{}, result:{}", requestId, "参数为空");
            return CommonResponseVo.failure("参数为空", requestId);
        }
        String requestParam = DESedeUtil.decryptMode(requestObject.getString("param"), decryptKey);

        // 参数校验
        if (StringUtils.isBlank(requestParam)) {
            log.error("requestId:{}, result:{}", requestId, "参数解密失败");
            return CommonResponseVo.failure("参数解密失败", requestId);
        }

        IdentityInfoDto identityInfoDto = JSON.toJavaObject(JSON.parseObject(requestParam), IdentityInfoDto.class);
        log.info("requestId:{},解密后参数:{}", requestId, identityInfoDto.toString());

        if (StringUtils.isBlank(identityInfoDto.getIdCode()) || StringUtils.isBlank(identityInfoDto.getName())) {
            log.error("requestId:{}, result:{}", requestId, "身份证号或姓名为空");
            return CommonResponseVo.failure("身份证号或姓名为空", requestId);
        }

        IdentityInfoPo po = new IdentityInfoPo();
        BeanUtils.copyProperties(identityInfoDto, po);
        po.setCreateTime(new Date());
        po.setRequestId(requestId);

        try {
            int result = mapper.insert(po);
            if (result == 1) {
                log.info("requestId:{}, result:{}", requestId, "成功");
                return CommonResponseVo.success("成功", requestId);
            } else {
                log.error("requestId:{}, result:{}", requestId, "新增失败");
                return CommonResponseVo.failure("新增失败", requestId);
            }
        } catch (Exception e) {
            log.error("requestId:{}, result:{}, 异常：{}", requestId, "新增失败", e.getMessage());
            return CommonResponseVo.failure("新增失败", requestId);
        }
    }

    @Override
    public List<String> getRequestIdByIdInfo(String idCode, String name) {
        return mapper.getRequestIdByIdInfo(idCode, name);
    }
}
